// These are sample initialization routines for some of the robot
// configurations we used during testing.  They show the kinds of things
// you might want to perform in the initialization.
// These routines will give errors if you do not include RROScommands.bas
// and make a call to InitRROScommands BEFORE using them. 
// Obviously the parameters should be changed to meet your needs.
// You may also want to delete some commands and add others.

InitRoboClawRobot:    // sample setup for our mansized prototype
  rCommport 49  
  delay 100
  SetTimeOut 5000
  rlocate 0,0
  rCommand(MotorSetup,ROBOCLAW)  // without encoders
  rCommand(SensorSetup,SIXRANGE+MAXBOTICS)  //+HMC6352)  
  rCommand(EnableCounters,0)
  rCommand(SetSpeed, 30) 
  rCommand(SetReducForwRight,0)
  rCommand(SetReducForwLeft,5)
  rCommand(SetReducBackRight,0)
  rCommand(SetReducBackLeft,10)
  rCommand(SetSlowDownSpeed,30)
  rCommand(SetMotorRamp,4)
  rCommand(SetMoveTime,6)
  rCommand(SetRotationTime,2)
  rCommand(SetCCdivisor,2)
  rCommand(SetClicksPerDiam,50)
  rCommand(SetClicksPer90,33)
  rCommand(SetTurnStyle,10)
  rCommand(SetBumpDist,5)
  rCommand(SetProxDist,13)
return

InitServoRobot:   // sample setup for our servomotor powered prototype
  rCommport 44
  delay 100
  SetTimeOut 30000
  rlocate 0,0
  rCommand(MotorSetup,1)
  rCommand(SensorSetup,DIGITAL+PING+HMC6352)
  rCommand(CalibServoDrive,0)
  rCommand(EnableCounters,0)
  rCommand(SetSpeed, 50) // speed
  rCommand(SetRightStopOffset,128)
  rCommand(SetLeftStopOffset,128)
  rCommand(SetReducForwRight,0)
  rCommand(SetReducForwLeft,0)
  rCommand(SetReducBackRight,0)
  rCommand(SetReducBackLeft,0)
  rCommand(SetSlowDownSpeed,30)
  rCommand(SetMotorRamp,10)
  rCommand(SetCCdivisor,2)
  rCommand(SetDriveServoDir,1)
  rCommand(SetDriveServoWidth,30)
return

InitDCrobot:   // sample setup for our DC motor powered prototype
  rCommport 47
  delay 100
  SetTimeOut 30000
  rlocate 0,0
  rCommand(MotorSetup,SMALLDC+ENCODERS) 
  rCommand(SensorSetup,SIXRANGE+IRSHORT)
  rCommand(EnableCounters,0)
  rCommand(SetMotorRamp,3) 
  rCommand(SetClicksPerDiam,30)
  rCommand(SetClicksPer90,9) 
  rCommand(SetReducForwRight,0)
  rCommand(SetReducForwLeft,5)
  rCommand(SetReducBackRight,0)
  rCommand(SetReducBackLeft,10)
  rCommand(SetRotationTime,2) 
  rCommand(SetMoveTime,6) 
  rCommand(SetSpeed,60) //80
  rCommand(SetSlowDownSpeed,40)   
  rCommand(SetCCdivisor,5)
  rCommand(SetBumpDist,5)
  rCommand(SetProxDist,10)
return

InitRB9robot:
  rCommport 47
  //delay 100
  SetTimeOut 50000
  rlocate 0,0 // 255,0
  rCommand(MotorSetup,SMALLDC+ENCODERS)  //+HMC6352 if you have a compass
 // rCommand(SensorSetup,0+PING) //3+FIVERANGE) //FIVERANGE+HMC6352) //0%10001000) rover 5
 rCommand (SensorSetup,SR04+FIVERANGE) // RB-9
  rCommand(SetMotorRamp,5)
  rCommand(SetClicksPerDiam,160)
  rCommand(SetClicksPer90,110) 
  rCommand(SetReducForwRight,0)
  rCommand(SetReducForwLeft,15)
  rCommand(SetReducBackRight,0)
  rCommand(SetReducBackLeft,0)
  rCommand(SetRotationTime,18) // 19)
  rCommand(SetMoveTime,12) //13) 
  rCommand(SetSpeed,55) //65) //,35)
  rCommand(SetSlowDownSpeed,40) //45) 
  rCommand(SetSlowDown2,25) 
  rCommand(SetCCdivisor,3)
  rCommand(SetBumpDist,10)
  rCommand(SetProxDist,15)
  rCommand(EnableCounters,1)
  rCommand(SetRobotAngle,90/2)
  rCommand(SetTurnStyle,100)
  rCommand(SetRROStimeout,15)
return

InitMagicianRobot:
  rCommport 47
  //delay 100
  SetTimeOut 50000
  rlocate 0,0
  rCommand(MotorSetup,SMALLDC) 
  rCommand (SensorSetup,DIGITAL+PING) // +HMC6352 if you have a compass
  rCommand(SetMotorRamp,5) 
  rCommand(SetReducForwRight,12)
  rCommand(SetReducForwLeft,0)
  rCommand(SetReducBackRight,0)
  rCommand(SetReducBackLeft,0)
  rCommand(SetRotationTime,19)
  rCommand(SetMoveTime,13) 
  rCommand(SetSpeed,35)
  rCommand(SetSlowDownSpeed,25)  
  rCommand(EnableCounters,0)
  rCommand(SetRobotAngle,90/2)
  rCommand(SetTurnStyle,100)
  rCommand(SetRROStimeout,15)
return        

InitRover5:
  rCommport 47
  SetTimeOut 50000
  rlocate 0,0 // 255,0
  rCommand(MotorSetup,SMALLDC+ENCODERS)  
  rCommand (SensorSetup,SR04+FIVERANGE) //+HMC6352 if you have a compass
  rCommand(SetMotorRamp,5)
  rCommand(SetClicksPerDiam,200)
  rCommand(SetClicksPer90,185)   // note: tanks do not make accurate turns
  rCommand(SetReducForwRight,0)
  rCommand(SetReducForwLeft,0)
  rCommand(SetReducBackRight,0)
  rCommand(SetReducBackLeft,0)
  rCommand(SetRotationTime,45)
  rCommand(SetMoveTime,14)
  rCommand(SetSpeed,65)
  rCommand(SetSlowDownSpeed,50) 
  rCommand(SetSlowDown2,40) 
  rCommand(SetCCdivisor,1) // need bigger correction for treds
  rCommand(SetBumpDist,10)
  rCommand(SetProxDist,15)
  rCommand(EnableCounters,1)
  rCommand(SetRobotAngle,90/2)
  rCommand(SetTurnStyle,100)
  rCommand(SetRROStimeout,15)
return 


